@@ -4,16 +4,18 @@ import google.oauth2.id_token
 
 from flask import g, request, session
 from google.auth.transport import requests as grequests
-from gaelib.env import (get_dashboard_url_prefix, 
-                        get_app_or_default_prop)
+from gaelib.env import (get_dashboard_url_prefix,
+                        get_app_or_default_prop,
+                        is_dashboard_url)
 from jose import jwt
 
 
-
 def configure_login_callback(callback):
   setattr(sys.modules[__name__], 'login_callback', callback)
 
+
 def get_user_id_and_token():
+
   auth_creds = request.authorization
 
   if auth_creds:
@@ -22,8 +24,16 @@ def get_user_id_and_token():
   else:
     user_id = session.get('gae_uid')
     id_token = session.get('gae_token')
-  auth_type = ''
 
+  # Overriding id_token if firebaseaccesstoken is found in the browser cookie
+  if is_dashboard_url() and 'firebaseAccessToken' in request.cookies:
+    id_token = str(request.cookies.get('firebaseAccessToken'))
+
+  return user_id, id_token
+
+
+def get_auth_type():
+  auth_type = ''
   try:
     auth_type = request.json.get('auth_type')
   except (AttributeError, KeyError):
@@ -50,14 +60,7 @@ def get_user_id_and_token():
   if not auth_type:
     auth_type = 'firebase'
 
-  url = request.path
-  is_dashboard_url = url.strip('/').startswith(get_dashboard_url_prefix())
-
-  # Overriding id_token if firebaseaccesstoken is found in the browser cookie
-  if is_dashboard_url and 'firebaseAccessToken' in request.cookies:
-    id_token = str(request.cookies.get('firebaseAccessToken'))
-
-  return user_id, id_token, auth_type, is_dashboard_url
+  return auth_type
 
 
 class Auth(object):
@@ -83,7 +86,6 @@ class Auth(object):
     )
     return claims
 
-
   def auth0_authorize(self):
     '''
         Authorize id_token with firebase,
@@ -95,22 +97,22 @@ class Auth(object):
     rsa_key = {}
     for key in jwks["keys"]:
       if key["kid"] == unverified_header["kid"]:
-          rsa_key = {
-              "kty": key["kty"],
-              "kid": key["kid"],
-              "use": key["use"],
-              "n": key["n"],
-              "e": key["e"]
-          }
+        rsa_key = {
+            "kty": key["kty"],
+            "kid": key["kid"],
+            "use": key["use"],
+            "n": key["n"],
+            "e": key["e"]
+        }
     if rsa_key:
       try:
-          payload = jwt.decode(
-              token,
-              rsa_key,
-              algorithms=["RS256"],
-              audience=get_app_or_default_prop('AUTH0_API_AUDIENCE'),
-              issuer="https://"+get_app_or_default_prop('AUTH0_DOMAIN')+"/"
-          )
+        payload = jwt.decode(
+            token,
+            rsa_key,
+            algorithms=["RS256"],
+            audience=get_app_or_default_prop('AUTH0_API_AUDIENCE'),
+            issuer="https://"+get_app_or_default_prop('AUTH0_DOMAIN')+"/"
+        )
       except jwt.ExpiredSignatureError:
         self.logger.error('Expired Signature for %s', self.id_token)
         payload = {}
