@@ -25,3 +25,5 @@ class User(model.Model):
   role = properties.IntegerProperty(choices=USER_ROLE_CHOICES)
   os = properties.StringProperty()
   device_notification_token = properties.StringProperty()
+  token = properties.StringProperty()
+  phone = properties.StringProperty()
